Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
Py.BytesInterface for Python values of type Bytes. With Python 2, aliases for String.
val of_string : string -> Object.tof_string s returns the Python byte sequence with the contents of s.
val of_bytes : Stdcompat.bytes -> Object.tSame as of_string but with an argument of type bytes.
val to_string : Object.t -> stringto_string o returns the string contained in the Python value o.
val to_bytes : Object.t -> Stdcompat.bytesSame as to_string but with an a result of type bytes.
val length : Object.t -> intlength s returns the length of the Python byte sequence s.