Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
Py.ListInterface for Python values of type List.
val check : Object.t -> boolcheck v returns true if v is a Python list.
val create : int -> Object.tWrapper for PyList_New
Equivalent to Sequence.get_item.
Wrapper for PyList_SetItem
val size : Object.t -> intWrapper for PyList_Size
init n f returns the Python list [f 0, f 1, ..., f (n - 1)].
of_array a returns the Python list with the same elements as a.
of_array_map f a returns the Python list (f a0, ..., f ak) where a0, ..., ak are the elements of a.
Equivalent to Sequence.to_array.
Equivalent to Sequence.to_array_map.
of_list l returns the Python list with the same elements as l.
of_list f l returns the Python list (f l1, ..., f ln) where l1, ..., ln are the elements of l. of_list_map f l is equivalent to of_list (List.map f l) but is tail-recursive and f is applied to the elements of l in the reverse order.
Equivalent to Sequence.to_list.
Equivalent to Sequence.to_list_map.
Equivalent to Sequence.fold_left.
Equivalent to Sequence.fold_right.
Equivalent to Sequence.for_all.
Equivalent to Sequence.exists.
Equivalent to Sequence.list.
val of_seq : Object.t Stdcompat.Seq.t -> Object.tof_seq s returns the Python list with the same elements as s.
val to_seq : Object.t -> Object.t Stdcompat.Seq.tEquivalent to Sequence.to_seq.
val to_seqi : Object.t -> (int * Object.t) Stdcompat.Seq.tEquivalent to Sequence.to_seqi.