Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
Py.Marshalval read_object_from_file : in_channel file -> Object.tread_object_from_file f reads one value from f and returns it. Wrapper for PyMarshal_ReadObjectFromFile
val load : in_channel file -> Object.tEquivalent to read_object_from_file.
val read_last_object_from_file : in_channel file -> Object.tread_last_object_from_file f reads a value from f and returns it. That value should be the only value remaining to be read from f before EOF. Wrapper for PyMarshal_ReadLastObjectFromFile
val read_object_from_string : string -> int -> Object.tread_object_from_string s len reads a value from the len first bytes of s. Wrapper for PyMarshal_ReadObjectFromString
val loads : string -> Object.tPy.Marshal.loads s is equivalent to Py.Marshal.read_object_from_string s (String.length s).
val write_object_to_file : Object.t -> out_channel file -> int -> unitwrite_object_to_file value file version writes the object value to file. version indicates the file format (use version to get the current version). Wrapper for PyMarshal_WriteObjectToFile
val dump : ?version:int -> Object.t -> out_channel file -> unitPy.Marshal.dump ?version value file is equivalent to Py.Marshal.write_object_to_file value file version. By default, the version returned by version is used.
write_object_to_file value file version returns the Python string representing the object value. version indicates the format (use version to get the current version). Wrapper for PyMarshal_WriteObjectToString